@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 import click
 from mynetwork.myip.myip import ip
+from mynetwork.speed.speed import speed
 
 
 @click.group()
@@ -10,6 +11,7 @@ def cli(ctx):
 
 
 cli.add_command(ip, "ip")
+cli.add_command(speed, "speed")
 
 
 def main():
