@@ -1,5 +1,8 @@
 import requests
 import click
+from rich.console import Console
+
+console = Console(log_path=False, log_time=False)
 
 
 def public_ip() -> requests.Response:
@@ -9,4 +12,4 @@ def public_ip() -> requests.Response:
 @click.command()
 def ip():
     response = public_ip()
-    print(response.text)
+    console.log(f'Public IP: {response.text}')
